"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.verifyV1 = exports.getVerifyV1InstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const types_1 = require("../types");
function getVerifyV1InstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['verifyV1Discriminator', s.u8()],
        [
            'authorizationData',
            s.option((0, types_1.getAuthorizationDataSerializer)(context)),
        ],
    ], { description: 'VerifyV1InstructionData' }), (value) => ({
        ...value,
        discriminator: 52,
        verifyV1Discriminator: 0,
    }));
}
exports.getVerifyV1InstructionDataSerializer = getVerifyV1InstructionDataSerializer;
function verifyV1(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const metadataAccount = input.metadata;
    const collectionAuthorityAccount = input.collectionAuthority;
    const payerAccount = input.payer ?? context.payer;
    const authorizationRulesAccount = input.authorizationRules ?? {
        ...programId,
        isWritable: false,
    };
    const authorizationRulesProgramAccount = input.authorizationRulesProgram ?? {
        ...programId,
        isWritable: false,
    };
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, true),
    });
    signers.push(collectionAuthorityAccount);
    keys.push({
        pubkey: collectionAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(collectionAuthorityAccount, true),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: authorizationRulesAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorizationRulesAccount, false),
    });
    keys.push({
        pubkey: authorizationRulesProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorizationRulesProgramAccount, false),
    });
    const data = getVerifyV1InstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return {
        instruction: { keys, programId, data },
        signers,
        bytesCreatedOnChain,
    };
}
exports.verifyV1 = verifyV1;
//# sourceMappingURL=verifyV1.js.map